@@ -163,6 +163,7 @@ class DatastoreAdminGrpcAsyncIOTransport(DatastoreAdminTransport):
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -259,6 +260,7 @@ class DatastoreAdminGrpcAsyncIOTransport(DatastoreAdminTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
