@@ -57,6 +57,9 @@ class PartitionId(proto.Message):
         project_id (str):
             The ID of the project to which the entities
             belong.
+        database_id (str):
+            If not empty, the ID of the database to which
+            the entities belong.
         namespace_id (str):
             If not empty, the ID of the namespace to
             which the entities belong.
@@ -66,6 +69,10 @@ class PartitionId(proto.Message):
         proto.STRING,
         number=2,
     )
+    database_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     namespace_id = proto.Field(
         proto.STRING,
         number=4,
@@ -121,9 +128,15 @@ class Key(proto.Message):
 
         Attributes:
             kind (str):
-                The kind of the entity. A kind matching regex ``__.*__`` is
-                reserved/read-only. A kind must not contain more than 1500
-                bytes when UTF-8 encoded. Cannot be ``""``.
+                The kind of the entity.
+
+                A kind matching regex ``__.*__`` is reserved/read-only. A
+                kind must not contain more than 1500 bytes when UTF-8
+                encoded. Cannot be ``""``.
+
+                Must be valid UTF-8 bytes. Legacy values that are not valid
+                UTF-8 are encoded as ``__bytes<X>__`` where ``<X>`` is the
+                base-64 encoding of the bytes.
             id (int):
                 The auto-allocated ID of the entity.
                 Never equal to zero. Values less than zero are
@@ -132,9 +145,15 @@ class Key(proto.Message):
 
                 This field is a member of `oneof`_ ``id_type``.
             name (str):
-                The name of the entity. A name matching regex ``__.*__`` is
-                reserved/read-only. A name must not be more than 1500 bytes
-                when UTF-8 encoded. Cannot be ``""``.
+                The name of the entity.
+
+                A name matching regex ``__.*__`` is reserved/read-only. A
+                name must not be more than 1500 bytes when UTF-8 encoded.
+                Cannot be ``""``.
+
+                Must be valid UTF-8 bytes. Legacy values that are not valid
+                UTF-8 are encoded as ``__bytes<X>__`` where ``<X>`` is the
+                base-64 encoding of the bytes.
 
                 This field is a member of `oneof`_ ``id_type``.
         """
